summaryrefslogtreecommitdiffstats
path: root/src/Bindings/ManualBindings_RankManager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/Bindings/ManualBindings_RankManager.cpp')
-rw-r--r--src/Bindings/ManualBindings_RankManager.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/Bindings/ManualBindings_RankManager.cpp b/src/Bindings/ManualBindings_RankManager.cpp
index 6e623af0d..3c58a0a92 100644
--- a/src/Bindings/ManualBindings_RankManager.cpp
+++ b/src/Bindings/ManualBindings_RankManager.cpp
@@ -204,11 +204,11 @@ static int tolua_cRankManager_GetAllPermissions(lua_State * L)
-/** Binds cRankManager::GetAllPlayers */
-static int tolua_cRankManager_GetAllPlayers(lua_State * L)
+/** Binds cRankManager::GetAllPlayerUUIDs */
+static int tolua_cRankManager_GetAllPlayerUUIDs(lua_State * L)
{
// Function signature:
// cRankManager:GetAllPlayers() -> arraytable of Player UUID's
cLuaState S(L);
if (
@@ -220,7 +220,7 @@ static int tolua_cRankManager_GetAllPlayers(lua_State * L)
}
// Get the player uuid's:
- AStringVector Players = cRoot::Get()->GetRankManager().GetAllPlayers();
+ AStringVector Players = cRoot::Get()->GetRankManager().GetAllPlayerUUIDs();
// Push the results:
S.Push(Players);
@@ -1055,7 +1055,7 @@ void ManualBindings::BindRankManager(lua_State * tolua_S)
tolua_function(tolua_S, "ClearPlayerRanks", tolua_cRankManager_ClearPlayerRanks);
tolua_function(tolua_S, "GetAllGroups", tolua_cRankManager_GetAllGroups);
tolua_function(tolua_S, "GetAllPermissions", tolua_cRankManager_GetAllPermissions);
- tolua_function(tolua_S, "GetAllPlayers", tolua_cRankManager_GetAllPlayers);
+ tolua_function(tolua_S, "GetAllPlayerUUIDs", tolua_cRankManager_GetAllPlayerUUIDs);
tolua_function(tolua_S, "GetAllRanks", tolua_cRankManager_GetAllRanks);
tolua_function(tolua_S, "GetDefaultRank", tolua_cRankManager_GetDefaultRank);
tolua_function(tolua_S, "GetGroupPermissions", tolua_cRankManager_GetGroupPermissions);
@@ -204,11 +204,11 @@ static int tolua_cRankManager_GetAllPermissions(lua_State * L)
{
// Function signature:
- // cRankManager:GetAllPlayers() -> arraytable of Player UUID's
+ // cRankManager:GetAllPlayerUUIDs() -> arraytable of Player UUID's
cLuaState S(L);
if (